import matplotlib.pyplot as plt

from .options import (
    get_ledger_args,
    parse_options,
)
from .munging import (
    clean_and_prepare,
    read_journal_csv,
)
from .plotting import (
    plot_assets,
    plot_budget,
    plot_cash_flow,
    plot_expenses,
    plot_net_worth,
)


def call_with_args(f, *args, **kwargs):
    valid_kwargs = {key: value for key, value in kwargs.items()
                    if value is not None}
    f(*args, **valid_kwargs)


def main():
    args = parse_options()
    ledger_args = get_ledger_args(args)
    journal = read_journal_csv(ledger_args)
    journal = clean_and_prepare(journal, args)

    all_plots = not any([args.budget, args.expenses, args.cash_flow,
                         args.assets, args.net_worth])

    if all_plots or args.budget:
        call_with_args(plot_budget,
                       journal,
                       level=args.level,
                       periods=args.periods,
                       freq=args.freq)

    if all_plots or args.expenses:
        call_with_args(plot_expenses,
                       journal,
                       level=args.level,
                       periods=args.periods,
                       freq=args.freq,
                       threshold=args.threshold)
    
    if all_plots or args.cash_flow:
        call_with_args(plot_cash_flow,
                       journal,
                       periods=args.periods,
                       freq=args.freq)

    if all_plots or args.assets:
        call_with_args(plot_assets,
                       journal,
                       level=args.level,
                       periods=args.periods,
                       freq=args.freq)

    if all_plots or args.net_worth:
        call_with_args(plot_net_worth,
                       journal,
                       periods=args.periods,
                       freq=args.freq)

    plt.show()
