import argparse


def get_ledger_options():
    options = {
        '--args-only': {
            'short': None,
            'action': 'store_true',
            'help': 'ignore init-file settings',
        },
        '--file': {
            'short': '-f',
            'action': 'append',
            'help': 'journal file',
        },
        '--real': {
            'short': '-R',
            'action': 'store_true',
            'help': 'ignore virtual transactions'
        }
    }
    return options


def add_ledger_arguments(parser):
    group = parser.add_argument_group('ledger arguments')
    ledger_options = get_ledger_options()
    for opt, params in ledger_options.items():
        if params['short'] is None:
            group.add_argument(opt,
                               action=params['action'],
                               help=params['help'])
        else:
            group.add_argument(opt, params['short'],
                               action=params['action'],
                               help=params['help'])


def parse_options():
    parser = argparse.ArgumentParser()

    parser.add_argument(
        '--budget',
        action='store_true',
        help='show the budget bar plot'
    )
    parser.add_argument(
        '--expenses',
        action='store_true',
        help='show the expenses pie plot'
    )
    parser.add_argument(
        '--threshold',
        type=float,
        help='fraction of total expenses below which accounts are grouped'
    )
    parser.add_argument(
        '--cash-flow',
        action='store_true',
        help='show the cash flow plot'
    )
    parser.add_argument(
        '--assets',
        action='store_true',
        help='show the assets area plot'
    )
    parser.add_argument(
        '--net-worth',
        action='store_true',
        help='show the net worth plot'
    )
    parser.add_argument(
        '--level',
        type=int,
        help='level of account categories to display'
    )
    parser.add_argument(
        '--periods',
        type=int,
        help='number of periods to generate'
    )
    parser.add_argument(
        '--freq',
        help='offset aliases'
    )

    add_ledger_arguments(parser)
    args = parser.parse_args()
    return args


def get_ledger_args(args):
    args_dict = vars(args)
    ledger_args = ['ledger', 'csv']
    for opt, params in get_ledger_options().items():
        name = opt.lstrip('-').replace('-', '_')
        if params['action'] == 'store_true' and args_dict[name]:
            ledger_args.append(opt)
        if params['action'] == 'append' and args_dict[name] is not None:
            for arg in args_dict[name]:
                ledger_args.append(opt)
                ledger_args.append(arg)
    return ledger_args
